@@ -3,10 +3,10 @@ global debug
 debug = "off"
 
 class server:
-    def send(email:str, *message:str):
+    def send(region:str, email:str, *message:str):
         if debug == "on":
             print("[3%] Debug mode ON")
-            print("[7%] Region UK")
+            print("[7%] Region "+region)
             print("[11%] Starting to get URL")
             print("[20%] Getting json from URL")
         url = "https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json"
@@ -24,11 +24,13 @@ class server:
         client.connect((ip, port))
         if debug == "on":
             print("[80%] Server connected!")
-        client.sendall(bytes("smtp|uk|"+email+"|"+message,'UTF-8'))
+        client.sendall(bytes("smtp|"+region+"|"+email+"|"+message,'UTF-8'))
         if debug == "on":
             print("[100%] Data send to server")
         code = client.recv(4096)
         return code
+    def regions():
+        return "SMTP regions: de, uk, au"
     def debug(type:str):
         global debug
         if type == "on":
